@@ -584,18 +584,19 @@ SEXP R_sparse_band(SEXP from, SEXP k1, SEXP k2)
 	UNPROTECT(1);
 
 	int a, b;
-	if (k1 == R_NilValue)
-		a = (m > 0) ? 1 - m : 0;
+	if (k1 == R_NilValue) // tril()
+		a = -m ; // was (m > 0) ? 1 - m : 0;
 	else if ((a = asInteger(k1)) == NA_INTEGER || a < -m || a > n)
-		error(_("'%s' must be an integer from %s to %s"),
-		      "k1", "-Dim[1]", "Dim[2]");
-	if (k2 == R_NilValue)
-		b = (n > 0) ? n - 1 : 0;
+		error(_("'%s' (%d) must be an integer from %s (%d) to %s (%d)"),
+		      "k1", a, "-Dim[1]", -m, "Dim[2]", n);
+	if (k2 == R_NilValue) // triu()
+		b = n; // was (n > 0) ? n - 1 : 0;
 	else if ((b = asInteger(k2)) == NA_INTEGER || b < -m || b > n)
-		error(_("'%s' must be an integer from %s to %s"),
-		      "k2", "-Dim[1]", "Dim[2]");
+		error(_("'%s' (%d) must be an integer from %s (%d) to %s (%d)"),
+		      "k2", b, "-Dim[1]", -m, "Dim[2]", n);
 	else if (b < a)
-		error(_("'%s' must be less than or equal to '%s'"), "k1", "k2");
+		error(_("'%s' (%d) must be less than or equal to '%s' (%d)"),
+		      "k1", a, "k2", b);
 
 	return sparse_band(from, valid[ivalid], a, b);
 }
@@ -2716,7 +2717,7 @@ void Csparse_colsum(SEXP obj, const char *class,
 	SEXP p0 = PROTECT(GET_SLOT(obj, Matrix_pSym));
 	int *pp0 = INTEGER(p0) + 1, j, k, kend, nnz1 = n, count = -1;
 
-	if (IS_S4_OBJECT(res)) {
+	if (isS4(res)) {
 
 		if (di == 'N') {
 			nnz1 = 0;
@@ -2800,7 +2801,7 @@ void Csparse_rowsum(SEXP obj, const char *class,
 	int *pp0 = INTEGER(p0) + 1, *pi0 = INTEGER(i0), i, j, k, kend,
 		nnz0 = pp0[n - 1], nnz1 = m;
 
-	if (IS_S4_OBJECT(res)) {
+	if (isS4(res)) {
 
 		int *work;
 		Matrix_Calloc(work, m, int);
@@ -2937,7 +2938,7 @@ void Tsparse_colsum(SEXP obj, const char *class,
 	int *pi0 = INTEGER(i0), *pj0 = INTEGER(j0), j, nnz1 = n;
 	R_xlen_t k, nnz0 = XLENGTH(i0);
 
-	if (IS_S4_OBJECT(res)) {
+	if (isS4(res)) {
 
 		int *work;
 		Matrix_Calloc(work, n, int);
